@@ -221,6 +221,16 @@ class LocalPorvider(BaseProvider):
         """
         return TDP.get_daily_aswsindexeod(instruments,fields,start_date,end_date)
 
+
+    def daily_cmfidxeod(self,instruments:list,fields:list,start_date:str,end_date:str):
+        """ 
+            table_name: 'AIndexIndustriesEODCITICS'
+            input:instruments:list,fields:list,start_date:str,end_date:str
+            output: DataFrame
+            fields: preclose open high low close change pctchange volume amount
+        """
+        return TDP.get_daily_cmfidxeod(instruments,fields,start_date,end_date)
+
     def daily_barra_dly_specret(self,instruments:list,fields:list,start_date:str,end_date:str):
         """
             table_name: "CNE5S_100_Asset_DlySpecRet"
