@@ -57,9 +57,10 @@ class TradeDayInfoProvider(BaseDailyTSInfoProvider):
     def get_sparse_daily_data(self,datapath,instruments,**kws):
         if isinstance(instruments,str):
             instruments = [instruments]
+        tidx = kws.get("tidx",self.tidx)
         defualt_si,defualt_ei = 0,1e7
         path = os.path.join(datapath,'merged.h5')
-        data = read_mergeh5(path,instruments,None,defualt_si,defualt_ei,self.tidx)
+        data = read_mergeh5(path,instruments,None,defualt_si,defualt_ei,tidx)
         if data.empty:
             return data
         if ("start_date" in kws)&("end_date" in kws):
