@@ -31,7 +31,7 @@ class BaseFincReportsProvider(abc.ABC):
 
 class LoacalFincReportsProvider(BaseFincReportsProvider):
 
-    def __init__(self, tidx=['report_period','ann_date']) -> None:
+    def __init__(self, tidx=['ann_date','report_period']) -> None:
         self.tidx = tidx
         super().__init__()
 
@@ -39,26 +39,22 @@ class LoacalFincReportsProvider(BaseFincReportsProvider):
         """ report table reader """
         if isinstance(instruments,str):
             instruments = [instruments]
+        tidx = kws.get("tidx",self.tidx)
         path = os.path.join(datapath,'merged.h5')
-        data = read_mergeh5(path,instruments,fields,defualt_si,defualt_ei,self.tidx)
+        data = read_mergeh5(path,instruments,fields,defualt_si,defualt_ei,tidx)
         if data.empty:
             return data
         if ("start_date" in kws)&("end_date" in kws):
             start_date,end_date = kws.get("start_date"),kws.get("end_date")
             sd,ed = to_intdate(start_date),to_intdate(end_date)
-            if kws.get('by',None) == self.tidx[0]:
-                data = data.loc[(data[self.tidx[0]] >= sd) & (data[self.tidx[0]] <= ed)]
-            else:
-                try:
-                    data = data.loc[(data[self.tidx[1]]>=sd)&(data[self.tidx[1]]<=ed)]
-                except KeyError:
-                    data = data.loc[(data['ann_dt']>=sd)&(data['ann_dt']<=ed)] # 部分表用的 ann_dt
+            by = kws.get('by',tidx[0])
+            data = data.loc[(data[by] >= sd) & (data[by] <= ed)]
 
-        if self.tidx[0] in kws:
-            tgt_rp = kws.get(self.tidx[0],None)
+        if self.tidx[1] in kws:
+            tgt_rp = kws.get(self.tidx[1],None)
             if not isinstance(tgt_rp,Iterable):
                 tgt_rp = [tgt_rp,]
-            data = data.loc[data[self.tidx[0]].isin(tgt_rp)]
+            data = data.loc[data[self.tidx[1]].isin(tgt_rp)]
         return data
 
     @print_func_time
@@ -109,7 +105,7 @@ class LoacalFundReportsProvider(BaseFincReportsProvider):
 
 
     
-    def __init__(self, tidx=['prt_enddate','ann_date']) -> None:
+    def __init__(self, tidx=['ann_date','prt_enddate']) -> None:
         self.tidx = tidx
         super().__init__()
 
@@ -117,31 +113,27 @@ class LoacalFundReportsProvider(BaseFincReportsProvider):
         """ report table reader """
         if isinstance(instruments,str):
             instruments = [instruments]
+        tidx = kws.get("tidx",self.tidx)
         path = os.path.join(datapath,'merged.h5')
-        data = read_mergeh5(path,instruments,fields,defualt_si,defualt_ei,self.tidx)
+        data = read_mergeh5(path,instruments,fields,defualt_si,defualt_ei,tidx)
         if data.empty:
             return data
         if ("start_date" in kws)&("end_date" in kws):
             start_date,end_date = kws.get("start_date"),kws.get("end_date")
             sd,ed = to_intdate(start_date),to_intdate(end_date)
-            if kws.get('by',None) == self.tidx[0]:
-                data = data.loc[(data[self.tidx[0]] >= sd) & (data[self.tidx[0]] <= ed)]
-            else:
-                try:
-                    data = data.loc[(data[self.tidx[1]]>=sd)&(data[self.tidx[1]]<=ed)]
-                except KeyError:
-                    data = data.loc[(data['ann_dt']>=sd)&(data['ann_dt']<=ed)] # 部分表用的 ann_dt
+            by = kws.get('by',tidx[0])
+            data = data.loc[(data[by] >= sd) & (data[by] <= ed)]
 
-        if self.tidx[0] in kws:
-            tgt_rp = kws.get(self.tidx[0],None)
+        if self.tidx[1] in kws:
+            tgt_rp = kws.get(self.tidx[1],None)
             if not isinstance(tgt_rp,Iterable):
                 tgt_rp = [tgt_rp,]
-            data = data.loc[data[self.tidx[0]].isin(tgt_rp)]
+            data = data.loc[data[self.tidx[1]].isin(tgt_rp)]
         return data
 
     @print_func_time
     def frepo_qdii_secuportfolio(self,instruments,fields,**kws):
-        return self.get_repo_data(fund_qdii_secu_portfolio,instruments,fields,**kws) 
+        return self.get_repo_data(fund_qdii_secu_portfolio,instruments,fields,tidx = ["ann_date","enddate"],**kws) 
 
     @print_func_time
     def frepo_mufund_stkportfolio(self,instruments,fields,**kws):
